@@ -1,4 +1,4 @@
-use crate::{Error, Pid};
+use crate::{Error, GpuCalculation, Pid};
 use ferrisetw::native::etw_types::EventRecord;
 use ferrisetw::parser::{Parser, TryParse};
 use ferrisetw::provider::Provider;
@@ -201,7 +201,7 @@ impl Pdh {
         }
     }
 
-    pub fn poll_gpu_usage(&mut self, pid: Option<Pid>) -> Option<f32> {
+    pub fn poll_gpu_usage(&mut self, pid: Option<Pid>, calc: GpuCalculation) -> Option<f32> {
         let counter = if let Some(pid) = pid {
             if let Some(counter) = self.process_gpu_counters.iter().find(|p| p.pid == pid) {
                 counter.counter
@@ -251,7 +251,16 @@ impl Pdh {
             assert_eq!(r, ERROR_SUCCESS as _);
 
             for i in 0..item_count {
-                sum = sum.max((*buffer[i as usize].FmtValue.u.doubleValue()) as f32);
+                let value = (*buffer[i as usize].FmtValue.u.doubleValue()) as f32;
+
+                match calc {
+                    GpuCalculation::Max => {
+                        sum = sum.max(value);
+                    }
+                    GpuCalculation::Sum => {
+                        sum += value;
+                    }
+                }
             }
         }
 
@@ -428,23 +437,9 @@ impl EtwTrace {
         let now = Instant::now();
         let d = (now - self.last_update).as_secs_f32();
         for value in self.handler.write().unwrap().trace_events.values_mut() {
-            value.present_per_sec = if d < 1.0 {
-                0.0
-            } else {
-                value.present as f32 / d
-            };
-
-            value.net_send_per_sec = if d < 1.0 {
-                0
-            } else {
-                (value.net_send as f32 / d) as _
-            };
-
-            value.net_recv_per_sec = if d < 1.0 {
-                0
-            } else {
-                (value.net_recv as f32 / d) as _
-            };
+            value.present_per_sec = value.present as f32 / d;
+            value.net_send_per_sec = (value.net_send as f32 / d) as _;
+            value.net_recv_per_sec = (value.net_recv as f32 / d) as _;
 
             value.present = 0;
             value.net_send = 0;
